@@ -12,6 +12,7 @@ module Parser
     parseExpressionThrows,
     parseAttribute,
     parseBinding,
+    parseBytes,
   )
 where
 
@@ -24,7 +25,7 @@ import Data.Sequence (mapWithIndex)
 import Data.Text.Internal.Fusion.Size (lowerBound)
 import Data.Void
 import GHC.Char (chr)
-import Misc (numToHex, strToHex, withVoidRho)
+import Misc
 import Numeric (readHex)
 import Text.Megaparsec
 import Text.Megaparsec.Char (alphaNumChar, char, digitChar, hexDigitChar, letterChar, lowerChar, space1, string, upperChar)
@@ -42,21 +43,6 @@ instance Show ParserException where
   show CouldNotParseProgram {..} = printf "Couldn't parse given phi program, cause: %s" message
   show CouldNotParseExpression {..} = printf "Couldn't parse given phi program, cause: %s" message
 
-dataExpression :: String -> String -> Expression
-dataExpression obj bts =
-  ExApplication
-    (ExDispatch (ExDispatch (ExDispatch ExGlobal (AtLabel "org")) (AtLabel "eolang")) (AtLabel obj))
-    ( BiTau
-        (AtAlpha 0)
-        ( ExApplication
-            (ExDispatch (ExDispatch (ExDispatch ExGlobal (AtLabel "org")) (AtLabel "eolang")) (AtLabel "bytes"))
-            ( BiTau
-                (AtAlpha 0)
-                (ExFormation [BiDelta bts, BiVoid AtRho])
-            )
-        )
-    )
-
 -- White space consumer
 whiteSpace :: Parser ()
 whiteSpace = L.space space1 empty empty
@@ -186,22 +172,26 @@ byte = do
       | otherwise = fail ("expected 0-9 or A-F, got " ++ show ch)
 
 -- bytes
+-- 0. meta: !b
 -- 1. empty: --
 -- 2. one byte: 01-
 -- 3. many bytes: 01-02-...-FF
-bytes :: Parser String
+bytes :: Parser Bytes
 bytes =
   lexeme
     ( choice
-        [ symbol "--",
+        [ BtMeta <$> meta' 'd' "δ",
+          symbol "--" >> return BtEmpty,
           try $ do
             first <- byte
             rest <- some $ do
-              dash <- char '-'
-              bte <- byte
-              return (dash : bte)
-            return (first ++ concat rest),
-          byte >>= \bte -> char '-' >>= \dash -> return (bte ++ [dash])
+              _ <- char '-'
+              byte
+            return (BtMany (first : rest)),
+          do
+            bte <- byte
+            _ <- char '-'
+            return (BtOne bte)
         ]
         <?> "bytes"
     )
@@ -245,9 +235,6 @@ binding =
       try $ do
         _ <- delta
         BiDelta <$> bytes,
-      try $ do
-        _ <- delta
-        BiMetaDelta <$> meta 'b',
       try metaBinding,
       try $ do
         _ <- lambda
@@ -345,11 +332,11 @@ exHead =
                     Just '-' -> negate unsigned
                     _ -> unsigned
                 )
-        return (dataExpression "number" (numToHex num)),
+        return (DataObject "number" (numToBts num)),
       lexeme $ do
         _ <- char '"'
         str <- manyTill (choice [escapedChar, noneOf ['\\', '"']]) (char '"')
-        return (dataExpression "string" (strToHex str)),
+        return (DataObject "string" (strToBts str)),
       try (ExMeta <$> meta' 'e' "𝑒"),
       ExDispatch ExThis <$> fullAttribute
     ]
@@ -439,6 +426,9 @@ parse' name parser input = do
     Right parsed' -> Right parsed'
     Left err -> Left (errorBundlePretty err)
 
+parseBytes :: String -> Either String Bytes
+parseBytes = parse' "bytes" bytes
+
 parseBinding :: String -> Either String Binding
 parseBinding = parse' "binding" binding
 
