@@ -5,12 +5,16 @@
 
 module Pretty
   ( prettyExpression,
+    prettyExpression',
     prettyProgram,
     prettyProgram',
     prettyAttribute,
     prettySubsts,
     prettySubsts',
+    prettySubst,
     prettyBinding,
+    prettyBytes,
+    prettyExtraArg,
     PrintMode (SWEET, SALTY),
   )
 where
@@ -21,6 +25,8 @@ import Matcher
 import Prettyprinter
 import Prettyprinter.Render.String (renderString)
 import Misc
+import Data.List (intercalate)
+import Yaml (ExtraArgument (..))
 
 data PrintMode = SWEET | SALTY
   deriving (Eq)
@@ -46,6 +52,18 @@ prettyRsb = pretty "⟧"
 prettyDashedArrow :: Doc ann
 prettyDashedArrow = pretty "⤍"
 
+instance Pretty ExtraArgument where
+  pretty (ArgExpression expr) = pretty (Formatted (SWEET, expr))
+  pretty (ArgBinding bd) = pretty (Formatted (SWEET, bd))
+  pretty (ArgAttribute attr) = pretty attr
+  pretty (ArgBytes bytes) = pretty bytes
+
+instance Pretty Bytes where
+  pretty BtEmpty = pretty "--"
+  pretty (BtOne bt) = pretty bt <> pretty "-"
+  pretty (BtMany bts) = pretty (intercalate "-" bts)
+  pretty (BtMeta meta) = prettyMeta meta
+
 instance Pretty Attribute where
   pretty (AtLabel name) = pretty name
   pretty (AtAlpha index) = pretty "α" <> pretty index
@@ -77,7 +95,6 @@ instance Pretty (Formatted Binding) where
   pretty (Formatted (_, BiMeta meta)) = prettyMeta meta
   pretty (Formatted (_, BiDelta bytes)) = pretty "Δ" <+> prettyDashedArrow <+> pretty bytes
   pretty (Formatted (_, BiMetaLambda meta)) = pretty "λ" <+> prettyDashedArrow <+> prettyMeta meta
-  pretty (Formatted (_, BiMetaDelta meta)) = pretty "Δ" <+> prettyDashedArrow <+> prettyMeta meta
   pretty (Formatted (_, BiVoid attr)) = pretty attr <+> prettyArrow <+> pretty "∅"
   pretty (Formatted (_, BiLambda func)) = pretty "λ" <+> prettyDashedArrow <+> pretty func
 
@@ -109,8 +126,8 @@ complexApplication (ExApplication expr tau) = (expr, [tau], [])
 
 instance Pretty (Formatted Expression) where
   pretty (Formatted (SWEET, ExDispatch (ExDispatch ExGlobal (AtLabel "org")) (AtLabel "eolang"))) = pretty "Φ̇"
-  pretty (Formatted (SWEET, DataObject "string" bytes)) = pretty "\"" <> pretty (hexToStr bytes) <> pretty "\""
-  pretty (Formatted (SWEET, DataObject "number" bytes)) = either pretty pretty (hexToNum bytes)
+  pretty (Formatted (SWEET, DataObject "string" bytes)) = pretty "\"" <> pretty (btsToStr bytes) <> pretty "\""
+  pretty (Formatted (SWEET, DataObject "number" bytes)) = either pretty pretty (btsToNum bytes)
   pretty (Formatted (SWEET, DataObject other bytes)) = pretty (Formatted (SALTY, DataObject other bytes))
   pretty (Formatted (mode, ExFormation [binding])) = case binding of
     BiTau _ _ -> vsep [pretty "⟦", indent 2 (pretty (Formatted (mode, binding))), pretty "⟧"]
@@ -182,9 +199,18 @@ render printable = renderString (layoutPretty defaultLayoutOptions (pretty print
 prettyBinding :: Binding -> String
 prettyBinding binding = render (Formatted (SALTY, binding))
 
+prettyExtraArg :: ExtraArgument -> String
+prettyExtraArg = render
+
+prettyBytes :: Bytes -> String
+prettyBytes = render
+
 prettyAttribute :: Attribute -> String
 prettyAttribute = render
 
+prettySubst :: Subst -> String
+prettySubst = render
+
 prettySubsts :: [Subst] -> String
 prettySubsts = render
 
@@ -194,6 +220,9 @@ prettySubsts' substs mode = render (Formatted (mode, substs))
 prettyExpression :: Expression -> String
 prettyExpression expr = render (Formatted (SALTY, expr))
 
+prettyExpression' :: Expression -> String
+prettyExpression' expr = render (Formatted (SWEET, expr))
+
 prettyProgram :: Program -> String
 prettyProgram prog = render (Formatted (SALTY, prog))
 
